@@ -977,7 +977,7 @@ static int insmod(DESC *desc, LINK **new_in_kernel, char *options[])
 
 	/* Something new for us to do? Or is the module already installed... */
 	if (desc == NULL || strcmp(desc->objkey, "null") == 0 ||
-	    runit && lookup_key(in_kernel, desc->kname) != NULL)
+	    (runit && lookup_key(in_kernel, desc->kname) != NULL))
 		return 0;
 	/* else */
 
@@ -1154,6 +1154,12 @@ static int insmod(DESC *desc, LINK **new_in_kernel, char *options[])
 
 			cmd[0] = '\0';
 			for (i = 0; i < my_argc; ++i) {
+				if ((strlen(cmd) + strlen(my_argv[i]) + 2) >= sizeof(cmd)) {
+					if ((strlen(cmd) + 5) >= sizeof(cmd))
+						cmd[sizeof(cmd)-5] = '\0';
+					xstrcat(cmd, " ...", sizeof(cmd));
+					break;
+				}
 				xstrcat(cmd, my_argv[i], sizeof(cmd));
 				if (i != my_argc - 1)
 					xstrcat(cmd, " ", sizeof(cmd));
@@ -1373,9 +1379,14 @@ static int modprobe_fromlist(int argc, char *argv[], char *type, int loadall)
 			do {
 				desc = NULL;
 				obj = g->pathv[alt];
-				ret = probe_stack(stripo(g->pathv[alt]), obj, options, &desc, &error_name);
-				if (ret >= -1) /* Some success */
-					++loaded;
+				if ( obj != NULL ) {
+					ret = probe_stack(stripo(g->pathv[alt]), obj, options, &desc, &error_name);
+					if (ret >= -1) /* Some success */
+						++loaded;
+				} else {
+					ret = -2;
+					error_name = NULL;
+				}
 			} while (++alt < g->pathc && (ret < -1 || loadall));
 		} else if ((g = any_probe_list(name))) {
 			ret = modprobe_fromlist(g->pathc, g->pathv, NULL, 0);
